@@ -46,16 +46,22 @@ except:
 from mercurial import mail
 from urllib2 import AbstractBasicAuthHandler, AbstractDigestAuthHandler
 
-# mercurial.demandimport incompatibility workaround,
-# would cause gnomekeyring, one of the possible
-# keyring backends, not to work.
+# mercurial.demandimport incompatibility workaround, various keyring
+# backends fail due to it.
 from mercurial.demandimport import ignore
-if "gobject._gobject" not in ignore:
-    ignore.append("gobject._gobject")
-    ignore.append("configparser")
-    ignore.append("json")
-    ignore.append("abc")
-    ignore.append("io")
+for blocked_module in [
+    "gobject._gobject",
+    "configparser",
+    "json",
+    "abc",
+    "io",
+    "keyring",
+    "gdata.docs.service",
+    "gdata.service",
+    "types",
+    ]:
+    if blocked_module not in ignore:
+        ignore.append(blocked_module)
 
 import keyring
 from urlparse import urlparse
